/**
 * An object that implements basic file system functionalities.
 */
export interface IFileSystem {
  /**
   * Asynchronously tests whether or not the given path exists by checking with the file system.
   * @param path A path to a file or directory.
   */
  exists(path: string): Promise<boolean>

  /**
   * Asynchronously reads the entire contents of a file.
   * @param path A path to a file.
   */
  readBuffer(path: string): Promise<Buffer>

  /**
   * Asynchronously reads the entire contents of a file.
   * @param path A path to a file.
   */
  readFile(path: string): Promise<string>

  /**
   * Asynchronously writes data to a file, replacing the file if it already exists.
   * @param path A path to a file.
   * @param data The data to write.
   */
  writeFile(path: string, data: string): Promise<void>

  /**
   * Asynchronous readdir(3) - read a directory.
   * @param path A path to a directory.
   */
  readdir(path: string): Promise<string[]>

  /**
   * Returns true if the path points to a directory.
   */
  isDirectory(path: string): Promise<boolean>
}

export interface IAdapter {
  /**
   * Underlying `fs` module. You can replace it with a wrapper of
   * `memfs` or any object that implements `IFileSystem`.
   */
  fs: IFileSystem

  /**
   * `SubtleCrypto` implementation. On Node.js this is
   * `require("crypto").webcrypto.subtle` and in the browser this is
   * `window.crypto.subtle`.
   */
  subtle: SubtleCrypto
}
