export function createEventEmitter<T = void>() {
  type EventListener = T extends void ? () => void : (value: T) => void
  type Emitter = T extends void
    ? { (): void; (listener: EventListener): () => void }
    : { (value: T): void; (listener: EventListener): () => void }

  const listeners = new Set<EventListener>()

  function emitter(value: T | EventListener) {
    if (typeof value === "function") {
      listeners.add(value as EventListener)
      return () => {
        listeners.delete(value as EventListener)
      }
    } else {
      listeners.forEach(fn => fn(value))
    }
  }
  return emitter as Emitter
}
