export function asyncMap<T, R>(
  list: T[],
  fn: (value: T, index: number, list: T[]) => Promise<R>
) {
  return Promise.all(list.map(fn))
}

export function setIfAbsent<K, V>(
  // @ts-expect-error
  map: Map<K, V> | WeakMap<K, V>,
  key: K,
  getValue: (key: K) => V
) {
  if (!map.has(key)) {
    const value = getValue(key)
    map.set(key, value)
    return value
  }
  return map.get(key)!
}

export function once<T extends (...args: any[]) => any>(fn: T): T {
  let result: ReturnType<T>
  let executed = false
  const res = function (this: ThisParameterType<T>) {
    if (executed) {
      return result
    } else {
      result = fn.apply(this, arguments as any as Parameters<T>)
      executed = true
      return result
    }
  }
  return res as any
}
