export class WeakValueMap<K, V extends object> {
  #map = new Map<K, WeakRef<V>>()

  #delete = (key: K) => {
    const value = this.#map.get(key)!
    this.#finalizers.unregister(value)
    this.#map.delete(key)
    return false
  }

  #finalizers = new FinalizationRegistry((key: K) => {
    this.#map.delete(key)
  })

  delete(key: K) {
    return this.#map.has(key) && !this.#delete(key)
  }

  has(key: K) {
    const has = this.#map.has(key)
    const value = has && !this.#map.get(key)!.deref()
    return value ? this.#delete(key) : has
  }

  get(key: K) {
    return this.#map.get(key)?.deref()
  }

  set(key: K, value: V) {
    this.delete(key)
    const ref = new WeakRef(value)
    this.#finalizers.register(value, key, ref)
    this.#map.set(key, ref)
    return this
  }

  clear(): void {
    this.#map.clear()
  }
}
