import { Category } from "opvault.js"
import { cx, css } from "@emotion/css"
import { BsBank2, BsPeopleFill } from "react-icons/bs"
import { CgLogIn } from "react-icons/cg"
import { HiMail, HiIdentification } from "react-icons/hi"
import { RiGovernmentLine } from "react-icons/ri"
import {
  FaArchive,
  FaDatabase,
  FaPassport,
  FaServer,
  FaFish,
  FaGift,
  FaCar,
  FaWifi,
} from "react-icons/fa"
import { GrLicense, GrNotes, GrCreditCard } from "react-icons/gr"
import { MdPassword } from "react-icons/md"

function getComponent(category: Category) {
  switch (category) {
    case Category.BankAccount:
      return BsBank2
    case Category.CreditCard:
      return GrCreditCard
    case Category.Database:
      return FaDatabase
    case Category.DriverLicense:
      return FaCar
    case Category.Email:
      return HiMail
    case Category.Identity:
      return HiIdentification
    case Category.Login:
      return CgLogIn
    case Category.Membership:
      return BsPeopleFill
    case Category.OutdoorLicense:
      return FaFish
    case Category.Passport:
      return FaPassport
    case Category.Password:
      return MdPassword
    case Category.Rewards:
      return FaGift
    case Category.Router:
      return FaWifi
    case Category.SecureNote:
      return GrNotes
    case Category.Server:
      return FaServer
    case Category.SoftwareLicense:
      return GrLicense
    case Category.SSN:
      return RiGovernmentLine
    case Category.Tombstone:
      return FaArchive
    default:
      category
  }
}

export const reactIconClass = css`
  fill: var(--color);
  @media (prefers-color-scheme: dark) {
    path:not([fill="none"]),
    path[stroke] {
      fill: #fff;
    }
  }
`

interface CategoryIconProps {
  className?: string
  style?: React.CSSProperties
  fill?: string
  category: Category
}

export const CategoryIcon: React.FC<CategoryIconProps> = ({
  className,
  category,
  style,
  fill,
}) => {
  const Component = getComponent(category)
  return Component ? (
    <Component className={cx(reactIconClass, className)} fill={fill} style={style} />
  ) : null
}
