import type { ErrorInfo } from "react"
import React from "react"
import styled from "@emotion/styled"

/**
 * @module ErrorBoundary
 * React HOC to restrict an Error from blowing up the entire application.
 */

type State = { error?: Error; info?: ErrorInfo }

const Div = styled.div`
  border: 1px solid #ddd;
  border-radius: 10px;
  box-shadow: rgba(0, 0, 0, 0.05) 0px 1px 1px;
  margin: 20px;
  padding: 20px;
`
const Header = styled.h2`
  font-weight: 600;
  margin: 0;
`
const Pre = styled.pre`
  font-size: 15px;
  line-height: 1.3em;
`

export class ErrorBoundary extends React.Component<any, State> {
  state: State = {}

  componentDidCatch(error: Error, info: ErrorInfo) {
    this.setState({ error, info })
  }

  render() {
    const { error, info } = this.state

    if (error) {
      console.error(error)
      return (
        <Div>
          <Header>Error: {error.message}</Header>
          <Pre>{info?.componentStack?.replace(/^\n/, "")}</Pre>
          <Pre>{error.stack}</Pre>
        </Div>
      )
    }

    return <>{this.props.children}</>
  }
}
