import type { OnePassword } from "opvault.js"
import styled from "@emotion/styled"
import { useCallback, useEffect, useState } from "react"

const Container = styled.div`
  padding: 20px;
  text-align: center;
`

export const Unlock: React.FC<{
  instance: OnePassword
  onUnlock(profile: string, password: string): void
}> = ({ onUnlock, instance }) => {
  const [profiles, setProfiles] = useState<string[]>(() => [])
  const [profile, setProfile] = useState<string>()
  const [password, setPassword] = useState("")

  const unlock = useCallback(() => {
    if (!profile) return
    onUnlock(profile, password)
    setPassword("")
  }, [onUnlock, profile, password])

  useEffect(() => {
    instance.getProfileNames().then(profiles => {
      setProfiles(profiles)
      setProfile(profiles[0])
    })
  }, [instance])

  return (
    <Container>
      <div>
        <select value={profile} onChange={e => setProfile(e.currentTarget.value)}>
          {profiles.map(p => (
            <option key={p} value={p}>
              Vault: {p}
            </option>
          ))}
        </select>
      </div>
      <div style={{ margin: "10px 0" }}>
        <input
          type="password"
          value={password}
          onChange={e => setPassword(e.currentTarget.value)}
        />
      </div>
      <button type="submit" disabled={!profile || !password} onClick={unlock}>
        Unlock
      </button>
    </Container>
  )
}
